# import os
# from pathlib import Path

# from bragir.config import CONFIG_FILE_PATH
# from bragir.tracing.logger import logger

# path = Path(CONFIG_FILE_PATH).expanduser()

# # if not os.path.isfile(path):
# #     logger.info(f"Config file not found at: {CONFIG_FILE_PATH}")

# #     logger.info(
# #         "Run the following command to create a new config file: `bragir config create`"
# #     )
# #     exit(1)
